# Examples

Examples of how to use earthkit-aggregate

```{toctree}
:caption: 'Notebooks'
:maxdepth: 1


notebooks/temporal/01-era5-general-methods.ipynb
notebooks/temporal/02-era5-daily-monthly-statistics.ipynb
notebooks/temporal/03-seas5-daily-statistics.ipynb
notebooks/aggregate-climatology.ipynb
notebooks/aggregate-spatial.ipynb
```
